@@ -40,15 +40,15 @@
 // include files for QT
 #include <QMetaObject>
 #include <QDir>
-#include <QPainter>
 #include <QInputDialog>
+#include <QMediaPlayer>
 
 // include files for KDE
 #include <KMessageBox>
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KConfig>
 #include <KStandardAction>
-#include <phonon/mediaobject.h>
 #include "ksirk_debug.h"
 #include <KToolBar>
 
@@ -69,14 +69,14 @@ bool KGameWindow::initArmiesMovement(unsigned int nbABouger, Country *firstCount
 
   if (firstCountry-> nbArmies() <= nbABouger)
   {
-    messageParts << I18N_NOOP("Cannot move %1 armies from %2 to %3") << QString::number(nbABouger)
+    messageParts << kli18n("Cannot move %1 armies from %2 to %3").untranslatedText() << QString::number(nbABouger)
       << firstCountry->name() << secondCountry->name();
     broadcastChangeItem(messageParts, ID_STATUS_MSG2, false);
     return false;
   }
   else
   {
-    messageParts << I18N_NOOP("Moving %1 armies from %2 to %3") << QString::number(nbABouger) << firstCountry->name() << secondCountry->name();
+    messageParts << kli18n("Moving %1 armies from %2 to %3").untranslatedText() << QString::number(nbABouger) << firstCountry->name() << secondCountry->name();
     broadcastChangeItem(messageParts, ID_STATUS_MSG2);
   }
 
@@ -103,7 +103,7 @@ bool KGameWindow::initArmiesMovement(unsigned int nbABouger, Country *firstCount
   }
   else 
   {
-    messageParts << I18N_NOOP("Cannot move %1 armies from %2 to %3") 
+    messageParts << kli18n("Cannot move %1 armies from %2 to %3") .untranslatedText()
       << QString::number(nbABouger) 
       << firstCountry->name() 
       << secondCountry->name();
@@ -154,7 +154,7 @@ AnimSprite* KGameWindow::initArmiesMultipleCombat(unsigned int nbA,
   // cannot comment out this comment below otherwise will use sprite uninitialized
   else
   {
-    messageParts << I18N_NOOP("Cannot move %1 armies from %2 to %3") 
+    messageParts << kli18n("Cannot move %1 armies from %2 to %3") .untranslatedText()
       << QString::number(nbA) 
       << firstCountry->name() 
       << secondCountry->name();
@@ -237,54 +237,8 @@ void KGameWindow::determinePointArrivee(
   qreal pointArriveeAttaquantX;
   qreal pointArriveeY;
   qreal pointArriveeDefenseurX;
-  qreal pointDepartAttaquantX;
-  qreal pointDepartDefenseurX;
-  qreal pointDepartAttaquantY;
-  qreal pointDepartDefenseurY;
   qreal leftRelativePos;
 
-  if (!attackingCountry->spritesInfantry().isEmpty())
-  {
-    // We must know
-    //  - attacker's departure point (pointInfantry)
-    pointDepartAttaquantX = attackingCountry-> pointInfantry().x()*m_theWorld->zoom();
-    pointDepartAttaquantY = attackingCountry-> pointInfantry().y()*m_theWorld->zoom();
-  }
-  else if (!attackingCountry->spritesCavalry().isEmpty())
-  {
-    // We must know
-    //  - attacker's departure point (pointCavalry)
-    pointDepartAttaquantX = attackingCountry-> pointCavalry().x()*m_theWorld->zoom();
-    pointDepartAttaquantY = attackingCountry-> pointCavalry().y()*m_theWorld->zoom();
-  }
-  else
-  {
-    // We must know
-    //  - attacker's departure point (pointCannon)
-      pointDepartAttaquantX = attackingCountry-> pointCannon().x()*m_theWorld->zoom();
-      pointDepartAttaquantY = attackingCountry-> pointCannon().y()*m_theWorld->zoom();
-  }
-
-  if (!defendingCountry->spritesInfantry().isEmpty())
-  {
-    //  - defender's departure point (pointInfantry)
-    pointDepartDefenseurX = defendingCountry-> pointInfantry().x()*m_theWorld->zoom();
-    pointDepartDefenseurY = defendingCountry-> pointInfantry().y()*m_theWorld->zoom();
-  
-  }
-  else if (!defendingCountry->spritesCavalry().isEmpty())
-  {
-    //  - defender's departure point (pointCavalry)
-    pointDepartDefenseurX = defendingCountry-> pointCavalry().x()* m_theWorld->zoom();
-    pointDepartDefenseurY = defendingCountry-> pointCavalry().y()* m_theWorld->zoom();
-  }
-  else
-  {
-    //  - defender's departure point (pointCannon)
-    pointDepartDefenseurX = defendingCountry-> pointCannon().x()*  m_theWorld->zoom();
-    pointDepartDefenseurY = defendingCountry-> pointCannon().y()*  m_theWorld->zoom();
-  }
-
   // vertical meet point
   int diff = Sprites::SkinSpritesData::single().intData("flag-height") - Sprites::SkinSpritesData::single().intData("cannon-height");
   pointArriveeY = (((defendingCountry-> pointFlag().y() + diff))* m_theWorld->zoom()) ;
@@ -380,8 +334,6 @@ void KGameWindow::determinePointArriveeForArena(
   qreal pointArriveeAttaquantX;
   qreal pointArriveeY;
   qreal pointArriveeDefenseurX;
-  qreal pointDepartAttaquantX;
-  qreal pointDepartDefenseurX;
   qreal pointDepartAttaquantY;
   qreal pointDepartDefenseurY;
   qreal leftRelativePos;
@@ -402,7 +354,6 @@ void KGameWindow::determinePointArriveeForArena(
     //  - attacker's departure point (pointInfantry)
     QPointF dep = determinePointDepartArena(attackingCountry, relative);
     qCDebug(KSIRK_LOG) << "dep=" << dep;
-    pointDepartAttaquantX = dep.x();
     pointDepartAttaquantY = dep.y();
   }
   else if (!attackingCountry->spritesCavalry().isEmpty())
@@ -410,7 +361,6 @@ void KGameWindow::determinePointArriveeForArena(
     qCDebug(KSIRK_LOG) << "cavalry" << attackingCountry->pointCavalry();
     // We must know
     //  - attacker's departure point (pointCavalry)
-    pointDepartAttaquantX = attackingCountry-> pointCavalry().x()*m_theWorld->zoom();
     pointDepartAttaquantY = attackingCountry-> pointCavalry().y()*m_theWorld->zoom();
   }
   else
@@ -418,7 +368,6 @@ void KGameWindow::determinePointArriveeForArena(
     qCDebug(KSIRK_LOG) << "cannon" << attackingCountry->pointCannon();
     // We must know
     //  - attacker's departure point (pointCannon)
-      pointDepartAttaquantX = attackingCountry-> pointCannon().x()*m_theWorld->zoom();
       pointDepartAttaquantY = attackingCountry-> pointCannon().y()*m_theWorld->zoom();
   }
 
@@ -451,7 +400,6 @@ void KGameWindow::determinePointArriveeForArena(
     qCDebug(KSIRK_LOG) << "infantry" << defendingCountry->name() << relative;
     //  - defender's departure point (pointInfantry)
     QPointF dep = determinePointDepartArena(defendingCountry, relative);
-    pointDepartDefenseurX = dep.x();
     pointDepartDefenseurY = dep.y();
     qCDebug(KSIRK_LOG) << "dep=" << dep;
   }
@@ -459,14 +407,12 @@ void KGameWindow::determinePointArriveeForArena(
   {
     qCDebug(KSIRK_LOG) << "cavalry" << defendingCountry->pointCavalry();
     //  - defender's departure point (pointCavalry)
-    pointDepartDefenseurX = defendingCountry-> pointCavalry().x()*m_theWorld->zoom();
     pointDepartDefenseurY = defendingCountry-> pointCavalry().y()*m_theWorld->zoom();
   }
   else
   {
     qCDebug(KSIRK_LOG) << "cannon" << defendingCountry->pointCannon();
     //  - defender's departure point (pointCannon)
-    pointDepartDefenseurX = defendingCountry-> pointCannon().x()*m_theWorld->zoom();
     pointDepartDefenseurY = defendingCountry-> pointCannon().y()*m_theWorld->zoom();
   }
 
@@ -694,7 +640,7 @@ void KGameWindow::initCombatMovement()
       }
       if (KsirkSettings::soundEnabled())
       {
-        m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndRoulePath));
+        m_audioPlayer->setSource(QUrl::fromLocalFile(sndRoulePath));
         m_audioPlayer->play();
       }
     }
@@ -809,7 +755,7 @@ void KGameWindow::initCombatMovement()
       }
       if (KsirkSettings::soundEnabled())
       {
-        m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndRoulePath));
+        m_audioPlayer->setSource(QUrl::fromLocalFile(sndRoulePath));
         m_audioPlayer->play();
       }
     }
@@ -854,7 +800,7 @@ void KGameWindow::animCombat()
     }
     if (KsirkSettings::soundEnabled())
     {
-      m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCanonPath));
+      m_audioPlayer->setSource(QUrl::fromLocalFile(sndCanonPath));
       m_audioPlayer->play();
     }
   }
@@ -929,7 +875,7 @@ void KGameWindow::animExplosion(int who)
         }
         if (KsirkSettings::soundEnabled())
         {
-          m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+          m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
           m_audioPlayer->play();
         }
       }
@@ -949,7 +895,7 @@ void KGameWindow::animExplosion(int who)
         }
         if (KsirkSettings::soundEnabled())
         {
-          m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+          m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
           m_audioPlayer->play();
         }
       }
@@ -989,7 +935,7 @@ void KGameWindow::animExplosion(int who)
   }
   if (KsirkSettings::soundEnabled())
   {
-    m_audioPlayer->setCurrentSource(sndCrashPath);
+    m_audioPlayer->setSource(sndCrashPath);
     m_audioPlayer->play();
   }*/
   qCDebug(KSIRK_LOG) << "finished";
@@ -1050,7 +996,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1087,7 +1033,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1122,7 +1068,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1176,7 +1122,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1213,7 +1159,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1247,7 +1193,7 @@ void KGameWindow::animExplosionForArena()
           }
           if (KsirkSettings::soundEnabled())
           {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndCrashPath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndCrashPath));
             m_audioPlayer->play();
           }
         }
@@ -1410,7 +1356,7 @@ void KGameWindow::initCombatBringBackForArena(Country *attackingCountry, Country
     }
     if (KsirkSettings::soundEnabled())
     {
-            m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndRoulePath));
+            m_audioPlayer->setSource(QUrl::fromLocalFile(sndRoulePath));
             m_audioPlayer->play();
     }
   }
@@ -1487,7 +1433,7 @@ void KGameWindow::initCombatBringBackForArena(Country *attackingCountry, Country
       }
       if (KsirkSettings::soundEnabled())
       {
-              m_audioPlayer->setCurrentSource(QUrl::fromLocalFile(sndRoulePath));
+              m_audioPlayer->setSource(QUrl::fromLocalFile(sndRoulePath));
               m_audioPlayer->play();
       }
   }
